==> static-compat-qt6-base-6.7.3-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6Core/Qt6CoreDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

# Make sure Qt6 is found before anything else.
set(Qt6Core_FOUND FALSE)

if("${_qt_cmake_dir}" STREQUAL "")
    set(_qt_cmake_dir "${QT_TOOLCHAIN_RELOCATABLE_CMAKE_DIR}")
endif()
set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# Don't propagate REQUIRED so we don't immediately FATAL_ERROR, rather let the find_dependency calls
# set _NOT_FOUND_MESSAGE which will be displayed by the includer of the Dependencies file.
set(${CMAKE_FIND_PACKAGE_NAME}_FIND_REQUIRED FALSE)

if(NOT Qt6_FOUND)
    find_dependency(Qt6 6.7.3
        PATHS
            ${QT_BUILD_CMAKE_PREFIX_PATH}
            "${CMAKE_CURRENT_LIST_DIR}/.."
            "${_qt_cmake_dir}"
            ${_qt_additional_packages_prefix_paths}
        ${__qt_use_no_default_path_for_qt_packages}
    )
endif()


# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_Core_third_party_deps "WrapZLIB\;FALSE\;\;\;;WrapAtomic\;FALSE\;\;\;;WrapBacktrace\;FALSE\;\;\;;WrapSystemDoubleConversion\;FALSE\;\;\;;Libb2\;FALSE\;\;\;;WrapPCRE2\;FALSE\;\;\;;WrapZSTD\;FALSE\;1.3\;\;;GLIB2\;FALSE\;\;\;")
_qt_internal_find_third_party_dependencies("Core" __qt_Core_third_party_deps)

# Find Qt tool package.
set(__qt_Core_tool_deps "Qt6CoreTools\;6.7.3")
_qt_internal_find_tool_dependencies("Core" __qt_Core_tool_deps)

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_Core_target_deps "")
set(__qt_Core_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/.." "${_qt_cmake_dir}")
_qt_internal_find_qt_dependencies("Core" __qt_Core_target_deps
                                  __qt_Core_find_dependency_paths)

set(_Qt6Core_MODULE_DEPENDENCIES "")
set(Qt6Core_FOUND TRUE)

==> static-compat-qt6-base-6.8.0-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6Core/Qt6CoreDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

# Make sure Qt6 is found before anything else.
set(Qt6Core_FOUND FALSE)

if("${_qt_cmake_dir}" STREQUAL "")
    set(_qt_cmake_dir "${QT_TOOLCHAIN_RELOCATABLE_CMAKE_DIR}")
endif()
set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# Don't propagate REQUIRED so we don't immediately FATAL_ERROR, rather let the find_dependency calls
# set _NOT_FOUND_MESSAGE which will be displayed by the includer of the Dependencies file.
set(${CMAKE_FIND_PACKAGE_NAME}_FIND_REQUIRED FALSE)

if(NOT Qt6_FOUND)
    find_dependency(Qt6 6.8.0
        PATHS
            ${QT_BUILD_CMAKE_PREFIX_PATH}
            "${CMAKE_CURRENT_LIST_DIR}/.."
            "${_qt_cmake_dir}"
            ${_qt_additional_packages_prefix_paths}
        ${__qt_use_no_default_path_for_qt_packages}
    )
endif()


# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_Core_third_party_deps "WrapZLIB\;FALSE\;\;\;;WrapAtomic\;FALSE\;\;\;;WrapBacktrace\;FALSE\;\;\;;WrapSystemDoubleConversion\;FALSE\;\;\;;Libb2\;FALSE\;\;\;;WrapPCRE2\;FALSE\;\;\;;WrapZSTD\;FALSE\;1.3\;\;;GLIB2\;FALSE\;\;\;")
set(__qt_Core_third_party_package_WrapZLIB_provided_targets "WrapZLIB::WrapZLIB")
set(__qt_Core_third_party_package_WrapAtomic_provided_targets "WrapAtomic::WrapAtomic")
set(__qt_Core_third_party_package_WrapBacktrace_provided_targets "WrapBacktrace::WrapBacktrace")
set(__qt_Core_third_party_package_WrapSystemDoubleConversion_provided_targets "WrapSystemDoubleConversion::WrapSystemDoubleConversion")
set(__qt_Core_third_party_package_Libb2_provided_targets "Libb2::Libb2")
set(__qt_Core_third_party_package_WrapPCRE2_provided_targets "WrapPCRE2::WrapPCRE2")
set(__qt_Core_third_party_package_WrapZSTD_provided_targets "WrapZSTD::WrapZSTD;zstd::libzstd;zstd::libzstd_static;zstd::libzstd_shared")
set(__qt_Core_third_party_package_GLIB2_provided_targets "GLIB2::GLIB2")

_qt_internal_find_third_party_dependencies("Core" __qt_Core_third_party_deps)

# Find Qt tool package.
set(__qt_Core_tool_deps "Qt6CoreTools\;6.8.0")
_qt_internal_find_tool_dependencies("Core" __qt_Core_tool_deps)

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_Core_target_deps "")
set(__qt_Core_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/.." "${_qt_cmake_dir}")
_qt_internal_find_qt_dependencies("Core" __qt_Core_target_deps
                                  __qt_Core_find_dependency_paths)

set(_Qt6Core_MODULE_DEPENDENCIES "")
set(Qt6Core_FOUND TRUE)
